==> forestry_1.11.2-5.3.4.140-sources.jar: forestry/farming/logic/FarmableRusticSapling.java <==
package forestry.farming.logic;

import net.minecraft.block.Block;
import net.minecraft.block.state.IBlockState;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.init.Blocks;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.util.math.BlockPos;
import net.minecraft.world.World;

import forestry.api.farming.ICrop;
import forestry.api.farming.IFarmable;
import forestry.core.network.packets.PacketFXSignal;
import forestry.core.utils.NetworkUtil;

public class FarmableRusticSapling implements IFarmable {

	protected final Item germling;
	protected final Block germlingBlock;
	private final ItemStack[] windfall;

	public FarmableRusticSapling(Item germling, ItemStack[] windfall) {
		this.germling = germling;
		this.germlingBlock = Block.func_149634_a(germling);
		this.windfall = windfall;
	}

	@Override
	public boolean plantSaplingAt(EntityPlayer player, ItemStack germling, World world, BlockPos pos) {
		if (world.func_175656_a(pos, germlingBlock.func_176203_a(germling.func_77952_i()))) {
			PacketFXSignal packet = new PacketFXSignal(PacketFXSignal.SoundFXType.BLOCK_PLACE, pos, germlingBlock.func_176203_a(germling.func_77952_i()));
			NetworkUtil.sendNetworkPacket(packet, pos, world);
			return true;
		}
		return false;
	}

	@Override
	public boolean isSaplingAt(World world, BlockPos pos) {
		return world.func_180495_p(pos).func_177230_c() == Blocks.field_150345_g;
	}

	@Override
	public ICrop getCropAt(World world, BlockPos pos, IBlockState blockState) {
		Block block = blockState.func_177230_c();
		if (!block.isWood(world, pos)) {
			return null;
		}

		return new CropDestroy(world, blockState, pos, null);
	}

	@Override
	public boolean isGermling(ItemStack itemstack) {
		return germling == itemstack.func_77973_b();
	}

	@Override
	public boolean isWindfall(ItemStack itemstack) {
		for (ItemStack drop : windfall) {
			if (drop.func_77969_a(itemstack)) {
				return true;
			}
		}
		return false;
	}
}

==> forestry_1.12.1-5.5.5.191-sources.jar: forestry/farming/logic/FarmableRusticSapling.java <==
package forestry.farming.logic;

import net.minecraft.block.Block;
import net.minecraft.block.state.IBlockState;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.util.math.BlockPos;
import net.minecraft.world.World;

import forestry.api.farming.ICrop;
import forestry.api.farming.IFarmable;
import forestry.core.network.packets.PacketFXSignal;
import forestry.core.utils.NetworkUtil;

public class FarmableRusticSapling implements IFarmable {

	protected final Item germling;
	protected final Block germlingBlock;
	private final ItemStack[] windfall;

	public FarmableRusticSapling(Item germling, ItemStack[] windfall) {
		this.germling = germling;
		this.germlingBlock = Block.func_149634_a(germling);
		this.windfall = windfall;
	}

	@Override
	public boolean plantSaplingAt(EntityPlayer player, ItemStack germling, World world, BlockPos pos) {
		if (world.func_175656_a(pos, germlingBlock.func_176203_a(germling.func_77952_i()))) {
			PacketFXSignal packet = new PacketFXSignal(PacketFXSignal.SoundFXType.BLOCK_PLACE, pos, germlingBlock.func_176203_a(germling.func_77952_i()));
			NetworkUtil.sendNetworkPacket(packet, pos, world);
			return true;
		}
		return false;
	}

	@Override
	public boolean isSaplingAt(World world, BlockPos pos) {
		return world.func_180495_p(pos).func_177230_c() == germlingBlock;
	}

	@Override
	public ICrop getCropAt(World world, BlockPos pos, IBlockState blockState) {
		Block block = blockState.func_177230_c();
		if (!block.isWood(world, pos)) {
			return null;
		}

		return new CropDestroy(world, blockState, pos, null);
	}

	@Override
	public boolean isGermling(ItemStack itemstack) {
		return germling == itemstack.func_77973_b();
	}

	@Override
	public boolean isWindfall(ItemStack itemstack) {
		for (ItemStack drop : windfall) {
			if (drop.func_77969_a(itemstack)) {
				return true;
			}
		}
		return false;
	}
}
